@@ -18,9 +18,25 @@ from django.urls import path, include
 from django.conf.urls import url
 from django.views import generic
 from material.frontend import urls as frontend_urls
+from django.contrib.sitemaps.views import sitemap
+from django.contrib import sitemaps
+
+class StaticViewSitemap(sitemaps.Sitemap):
+    priority = 0.5
+    changefreq = 'daily'
+
+    def items(self):
+        return ['calendar', 'workflow', 'license']
+
+    def location(self, item):
+        return reverse(item)
 
 urlpatterns = [
-    path('admin/', admin.site.urls),
+    #path('admin/', admin.site.urls),
     path('', include(frontend_urls)),
-    url('^$', generic.RedirectView.as_view(url='./corgy_payroll/'), name="index"),
+    path('i18n/', include('django.conf.urls.i18n')),
+    url('avatar/', include('avatar.urls')),
+    path('pages/', include('django.contrib.flatpages.urls')),
+    url('^$', generic.RedirectView.as_view(url='./workflow/'), name="index"),
+    path('sitemap.xml', sitemap, {'sitemaps': sitemaps}, name='django.contrib.sitemaps.views.sitemap')
 ]
